@@ -932,6 +932,7 @@ class TestGdal:
     @requires_data
     @requires_secrets
     @requires_gdal
+    @pytest.mark.xfail(strict=False)
     def test_get_raster_elevation(self):
         filename = "geo/N39W028.SRTMGL3.hgt.zip"
         geofile = util.get_wradlib_data_file(filename)
@@ -955,7 +956,6 @@ class TestGdal:
 
     @requires_gdal
     def test_get_raster_extent(self, gdal_data):
-
         extent = georef.get_raster_extent(gdal_data.ds2)
         window_map = np.array([3e5, 1e6, 3e5, 1e6])
         np.testing.assert_array_almost_equal(extent, window_map, decimal=3)
@@ -1406,6 +1406,8 @@ class TestVector:
     @requires_data
     @requires_gdal
     def test_get_vector_coordinates(self, vec_data):
+        util.get_wradlib_data_file("shapefiles/agger/agger_merge.dbf")
+        util.get_wradlib_data_file("shapefiles/agger/agger_merge.shx")
         filename = util.get_wradlib_data_file("shapefiles/agger/agger_merge.shp")
         proj_gk2 = osr.SpatialReference()
         proj_gk2.ImportFromEPSG(31466)
